==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_zh.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=zh
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => '只为未来的文章 (数据库无动作).',
	'bouton_radio_articles_tous' => '为所有文章.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => '为所有文章,除了那些论坛尚未激活的.',
	'bouton_radio_enregistrement_obligatoire' => '必须注册 
(在能发表出版物前
用户必须提供电子邮件订阅).',
	'bouton_radio_moderation_priori' => '预存 (
 出版物只能管理员确认
 才能显示出来).', # MODIF
	'bouton_radio_modere_abonnement' => '通过订阅预存', # MODIF
	'bouton_radio_modere_posteriori' => '预存后', # MODIF
	'bouton_radio_modere_priori' => '预存前', # MODIF
	'bouton_radio_publication_immediate' => '直接消息出版物
 (投稿发送后可显示, 管理员可以
 删除它们).',

	// F
	'form_pet_message_commentaire' => '其它消息和评论?',
	'forum' => '论坛',
	'forum_acces_refuse' => '您已经无权访问这些论坛.',
	'forum_attention_dix_caracteres' => '<b>警告!</b> 您的消息少于十个字符.', # MODIF
	'forum_attention_trois_caracteres' => '<b>警告!</b> 您的标题少于三个字符.', # MODIF
	'forum_avez_selectionne' => '您已选择:',
	'forum_cliquer_retour' => '单击 <a href=\'@retour_forum@\'>这里</a> 继续.',
	'forum_forum' => '论坛',
	'forum_info_modere' => '论坛是预缓冲的: 您的投稿只有被站点管理员确认才能显示.', # MODIF
	'forum_lien_hyper' => '<b>超链接</b> (可选)', # MODIF
	'forum_message_definitif' => '最后消息: 发送到站点',
	'forum_message_trop_long' => '您的消息过长. 最大长度为20000个字符.', # MODIF
	'forum_ne_repondez_pas' => '请勿回复该信件,请到如下地址的论坛回复:', # MODIF
	'forum_page_url' => '(如果您的消息引用了web上发表的文章请提供进一步的消息, 请输入页头和它的URL).',
	'forum_poste_par' => '您文章@parauteur@之后后发表的信息.', # MODIF
	'forum_qui_etes_vous' => '<b>您是谁?</b> (可选)', # MODIF
	'forum_texte' => '消息正文:', # MODIF
	'forum_titre' => '标题:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => '使选择生效',
	'forum_voir_avant' => '发表前预览', # MODIF
	'forum_votre_email' => '您的邮件地址:', # MODIF
	'forum_votre_nom' => '您的名字(或昵称):', # MODIF
	'forum_vous_enregistrer' => '在参与论坛前,您必须注册. 谢谢您填写已经递交过的个人信息.
如果你您尚未注册, 您必须',
	'forum_vous_inscrire' => '请注册。',

	// I
	'icone_poster_message' => '发表消息',
	'icone_suivi_forum' => '跟踪公共论坛: @nb_forums@ 出版物',
	'icone_suivi_forums' => '跟踪/管理论坛',
	'icone_supprimer_message' => '删除消息',
	'icone_valider_message' => '使消息有效',
	'info_activer_forum_public' => '<i>若要激活公共论坛, 请选择默认模式:</i>', # MODIF
	'info_appliquer_choix_moderation' => '应用缓冲选择:',
	'info_desactiver_forum_public' => '停用公共论坛.
 公共论坛只能通过一篇一篇文章的访问;
它们的专栏和简要等将被禁止.',
	'info_envoi_forum' => '发送论坛给文章作者 ',
	'info_fonctionnement_forum' => '论坛操作:',
	'info_gauche_suivi_forum_2' => ' <i>论坛跟踪</i> 页是你站点的一个管理工具(不是讨论或编辑). 它显示这篇文章的所有论坛出版物并允许你管理这些出版物.', # MODIF
	'info_liens_syndiques_3' => '论坛',
	'info_liens_syndiques_4' => '是',
	'info_liens_syndiques_5' => '论坛',
	'info_liens_syndiques_6' => '是',
	'info_liens_syndiques_7' => '未确认.',
	'info_mode_fonctionnement_defaut_forum_public' => '公众论坛的缺省模式',
	'info_option_email' => '当一个站点访问者在论坛发表一个关联文章的消息
  , 文章的作者能被电子邮件通知
  . 你愿意用这个选项吗?', # MODIF
	'info_pas_de_forum' => '没有论坛',
	'item_activer_forum_administrateur' => '激活管理者论坛',
	'item_desactiver_forum_administrateur' => '使管理论坛不可用',

	// L
	'lien_reponse_article' => '回应文章',
	'lien_reponse_breve_2' => '回应新闻',
	'lien_reponse_rubrique' => '回应专栏',
	'lien_reponse_site_reference' => '回应到参考站点:', # MODIF

	// O
	'onglet_messages_internes' => '内容消息',
	'onglet_messages_publics' => '公众消息',
	'onglet_messages_vide' => '无文字消息',

	// R
	'repondre_message' => '回复消息',

	// T
	'titre_cadre_forum_administrateur' => '管理者私有论坛',
	'titre_cadre_forum_interne' => '内部论坛',
	'titre_forum' => '内部论坛',
	'titre_forum_suivi' => '论坛跟踪',
	'titre_page_forum_suivi' => '论坛跟踪'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_zh.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=zh
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => '只为未来的文章 (数据库无动作).',
	'bouton_radio_articles_tous' => '为所有文章.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => '为所有文章,除了那些论坛尚未激活的.',
	'bouton_radio_enregistrement_obligatoire' => '必须注册 
(在能发表出版物前
用户必须提供电子邮件订阅).',
	'bouton_radio_moderation_priori' => '预存 (
 出版物只能管理员确认
 才能显示出来).', # MODIF
	'bouton_radio_modere_abonnement' => '通过订阅预存', # MODIF
	'bouton_radio_modere_posteriori' => '预存后', # MODIF
	'bouton_radio_modere_priori' => '预存前', # MODIF
	'bouton_radio_publication_immediate' => '直接消息出版物
 (投稿发送后可显示, 管理员可以
 删除它们).',

	// F
	'form_pet_message_commentaire' => '其它消息和评论?',
	'forum' => '论坛',
	'forum_acces_refuse' => '您已经无权访问这些论坛.',
	'forum_attention_dix_caracteres' => '<b>警告!</b> 您的消息少于十个字符.', # MODIF
	'forum_attention_trois_caracteres' => '<b>警告!</b> 您的标题少于三个字符.', # MODIF
	'forum_avez_selectionne' => '您已选择:',
	'forum_cliquer_retour' => '单击 <a href=\'@retour_forum@\'>这里</a> 继续.',
	'forum_forum' => '论坛',
	'forum_info_modere' => '论坛是预缓冲的: 您的投稿只有被站点管理员确认才能显示.', # MODIF
	'forum_lien_hyper' => '<b>超链接</b> (可选)', # MODIF
	'forum_message_definitif' => '最后消息: 发送到站点',
	'forum_message_trop_long' => '您的消息过长. 最大长度为20000个字符.', # MODIF
	'forum_ne_repondez_pas' => '请勿回复该信件,请到如下地址的论坛回复:', # MODIF
	'forum_page_url' => '(如果您的消息引用了web上发表的文章请提供进一步的消息, 请输入页头和它的URL).',
	'forum_poste_par' => '您文章@parauteur@之后后发表的信息.', # MODIF
	'forum_qui_etes_vous' => '<b>您是谁?</b> (可选)', # MODIF
	'forum_texte' => '消息正文:', # MODIF
	'forum_titre' => '标题:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => '使选择生效',
	'forum_voir_avant' => '发表前预览', # MODIF
	'forum_votre_email' => '您的邮件地址:', # MODIF
	'forum_votre_nom' => '您的名字(或昵称):', # MODIF
	'forum_vous_enregistrer' => '在参与论坛前,您必须注册. 谢谢您填写已经递交过的个人信息.
如果你您尚未注册, 您必须',
	'forum_vous_inscrire' => '请注册。',

	// I
	'icone_poster_message' => '发表消息',
	'icone_suivi_forum' => '跟踪公共论坛: @nb_forums@ 出版物',
	'icone_suivi_forums' => '跟踪/管理论坛',
	'icone_supprimer_message' => '删除消息',
	'icone_valider_message' => '使消息有效',
	'info_activer_forum_public' => '<i>若要激活公共论坛, 请选择默认模式:</i>', # MODIF
	'info_appliquer_choix_moderation' => '应用缓冲选择:',
	'info_desactiver_forum_public' => '停用公共论坛.
 公共论坛只能通过一篇一篇文章的访问;
它们的专栏和简要等将被禁止.',
	'info_envoi_forum' => '发送论坛给文章作者 ',
	'info_fonctionnement_forum' => '论坛操作:',
	'info_gauche_suivi_forum_2' => ' <i>论坛跟踪</i> 页是你站点的一个管理工具(不是讨论或编辑). 它显示这篇文章的所有论坛出版物并允许你管理这些出版物.', # MODIF
	'info_liens_syndiques_3' => '论坛',
	'info_liens_syndiques_4' => '是',
	'info_liens_syndiques_5' => '论坛',
	'info_liens_syndiques_6' => '是',
	'info_liens_syndiques_7' => '未确认.',
	'info_mode_fonctionnement_defaut_forum_public' => '公众论坛的缺省模式',
	'info_option_email' => '当一个站点访问者在论坛发表一个关联文章的消息
  , 文章的作者能被电子邮件通知
  . 你愿意用这个选项吗?', # MODIF
	'info_pas_de_forum' => '没有论坛',
	'item_activer_forum_administrateur' => '激活管理者论坛',
	'item_desactiver_forum_administrateur' => '使管理论坛不可用',

	// L
	'lien_reponse_article' => '回应文章',
	'lien_reponse_breve_2' => '回应新闻',
	'lien_reponse_rubrique' => '回应专栏',
	'lien_reponse_site_reference' => '回应到参考站点:', # MODIF

	// O
	'onglet_messages_internes' => '内容消息',
	'onglet_messages_publics' => '公众消息',
	'onglet_messages_vide' => '无文字消息',

	// R
	'repondre_message' => '回复消息',

	// T
	'titre_cadre_forum_administrateur' => '管理者私有论坛',
	'titre_cadre_forum_interne' => '内部论坛',
	'titre_forum' => '内部论坛',
	'titre_forum_suivi' => '论坛跟踪',
	'titre_page_forum_suivi' => '论坛跟踪',
];
